<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package CodeVibrant
 * @subpackage Perfect Plus
 * @since 1.0.0
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site">

	<div class="cv-top-header">
		<div class="cv-container">
			<div class="cv-top-left">
				<?php
					$top_header_left_content = get_theme_mod( 'top_header_left_content', 'social_icon' );
					if( $top_header_left_content == 'social_icon' ) {
						perfect_plus_social_media_icons();
					} else {
				?>
						<nav id="top-navigation" class="top-navigation">
							<?php wp_nav_menu( array( 'theme_location' => 'perfect_plus_top_menu', 'fallback_cb' => false, 'menu_id' => 'top-menu' ) ); ?>
						</nav><!-- #top-navigation -->
				<?php
					}
				?>
			</div><!-- .cv-top-left -->
			<div class="cv-top-right">
				<?php
					$top_phone   = get_theme_mod( 'top_header_phone', '' );
					$top_email   = get_theme_mod( 'top_header_email', '' );
					$top_address = get_theme_mod( 'top_header_address', '' );
					if( !empty( $top_phone ) ) {
						echo '<span class="cv-info cv-top-phone"><a href="tel:'. esc_attr( $top_phone ) .'">'. esc_html( $top_phone ) .'</a></span>';
					}
					if( !empty( $top_email ) ) {
						echo '<span class="cv-info cv-top-email"><a href="mailto:'. esc_attr( $top_email ) .'">'. esc_html( $top_email ) .'</a></span>';
					}
					if( !empty( $top_address ) ) {
						echo '<span class="cv-info cv-top-email">'. esc_html( $top_address ) .'</span>';
					}
				?>
			</div><!-- .cv-top-right -->
		</div>
	</div><!-- .cv-top-header -->

	<header id="masthead" class="site-header">
		<div class="cv-container">
			<div class="site-branding">
				<?php
				the_custom_logo();
				if ( is_front_page() || is_home() ) : ?>
					<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
				<?php else : ?>
					<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
				<?php
				endif;

				$description = get_bloginfo( 'description', 'display' );
				if ( $description || is_customize_preview() ) : ?>
					<p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
				<?php
				endif; ?>
			</div><!-- .site-branding -->

			<div class="cv-menu-wrapper">
                <div class="menu-toggle"><i class="fa fa-bars"></i></div>
				<nav id="site-navigation" class="main-navigation">
					<?php wp_nav_menu( array( 'theme_location' => 'perfect_plus_primary_menu', 'menu_id' => 'primary-menu', ) ); ?>
				</nav><!-- #site-navigation -->
				<div class="cv-menu-extra-wrap">
					<div class="cv-menu-search">
						<div class="cv-search-icon"> <i class="fa fa-search"></i></div>
						<?php get_search_form(); ?>
					</div>
					<?php perfect_plus_header_cart(); ?>
				</div><!-- .menu-extra-wrap -->
			</div><!-- .cv-menu-wrapper -->
		</div>
	</header><!-- #masthead -->

	<?php 
		if( ! is_page_template( 'templates/home-template.php' ) && !is_front_page() ) {
			$inner_header_attribute = '';
			$inner_header_attribute = apply_filters( 'perfect_plus_inner_header_style_attribute', $inner_header_attribute );
			if( !empty( $inner_header_attribute ) ) {
				$header_class = 'has-bg-img';
			} else {
				$header_class = 'no-bg-img';
			}
	?>
		<div class="custom-header <?php echo esc_attr( $header_class ); ?>" <?php echo ( ! empty( $inner_header_attribute ) ) ? ' style="' . esc_attr( $inner_header_attribute ) . '" ' : ''; ?>>
            <div class="cv-container">
    			<?php
    				if( is_single() || is_page() ) {
    					the_title( '<h1 class="entry-title">', '</h1>' );
    				}elseif( is_home() ) {
    				   echo '<h1 class="entry-title">'. apply_filters( 'the_title', get_the_title( get_option( 'page_for_posts' ) ) ) .'</h1>';
    				} elseif( is_archive() ) {
    					if( is_woocommerce_activated() && is_shop() ) {
    				?>
    						<h1 class="woocommerce-products-header__title page-title"><?php woocommerce_page_title(); ?></h1>
    				<?php
    					} else {
    						the_archive_title( '<h1 class="page-title">', '</h1>' );
    						the_archive_description( '<div class="taxonomy-description">', '</div>' );
    					}
    				} elseif( is_search() ) {
    			?>
    					<h1 class="page-title"><?php printf( esc_html__( 'Search Results for: %s', 'perfect-plus' ), '<span>' . get_search_query() . '</span>' ); ?></h1>
    			<?php
    				} elseif( is_404() ) {
    					echo '<h1 class="entry-title">'. esc_html( '404 Error', 'perfect-plus' ) .'</h1>';
    				}
    			?>
    			<?php perfect_plus_inner_breadcrumb(); ?>
            </div><!-- .cv-container -->
		</div><!-- .custom-header -->
	<?php } ?>

	<div id="content" class="site-content">
		<?php
			if( ! is_page_template( 'templates/home-template.php' ) ) {
	        	echo '<div class="cv-container">';
	    	}
		?>
