<?php
/**
 * Define customizer custom classes
 *
 * @package CodeVibrant
 * @subpackage Perfect Plus
 * @since 1.0.0
 */

if( class_exists( 'WP_Customize_Control' ) ) {

/*----------------------------------------------------------------------------------------------------------------------------------------*/
	/**
     * Radio toggle customize control.
     *
     * @since  1.0.0
     * @access public
     */
    class Perfect_Plus_Toggle_Checkbox_Custom_Control extends WP_Customize_Control {

		/**
		 * The type of control being rendered
		 */
		public $type = 'toogle_checkbox';
		
		/**
		 * Render the control in the customizer
		 */
		public function render_content(){
		?>
			<div class="cv-toggle-checkbox-wrap">
				<input id="<?php echo esc_attr( $this->id ); ?>" class="cv-checkbox-toggle" type="checkbox" <?php $this->link(); checked( true, $this->value() ); ?> data-toggle="toggle" data-style="slow" >
				<label for="<?php echo esc_attr( $this->id ); ?>"><?php echo esc_html( $this->label ); ?></label>
				<span id="_customize-description-<?php echo esc_attr( $this->id ); ?>" class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
			</span>
		<?php
		}
	}

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Radio image customize control.
     *
     * @since  1.0.0
     * @access public
     */
    class Perfect_Plus_Customize_Control_Radio_Image extends WP_Customize_Control {
        /**
         * The type of customize control being rendered.
         *
         * @since  1.0.0
         * @access public
         * @var    string
         */
        public $type = 'radio-image';

        /**
         * Loads the jQuery UI Button script and custom scripts/styles.
         *
         * @since  1.0.0
         * @access public
         * @return void
         */
        public function enqueue() {
            wp_enqueue_script( 'jquery-ui-button' );
        }

        /**
         * Add custom JSON parameters to use in the JS template.
         *
         * @since  1.0.0
         * @access public
         * @return void
         */
        public function to_json() {
            parent::to_json();

            // We need to make sure we have the correct image URL.
            foreach ( $this->choices as $value => $args )
                $this->choices[ $value ]['url'] = esc_url( sprintf( $args['url'], get_template_directory_uri(), get_stylesheet_directory_uri() ) );

            $this->json['choices'] = $this->choices;
            $this->json['link']    = $this->get_link();
            $this->json['value']   = $this->value();
            $this->json['id']      = $this->id;
        }


        /**
         * Underscore JS template to handle the control's output.
         *
         * @since  1.0.0
         * @access public
         * @return void
         */

        public function content_template() { ?>
            <# if ( data.label ) { #>
                <span class="customize-control-title">{{ data.label }}</span>
            <# } #>

            <# if ( data.description ) { #>
                <span class="description customize-control-description">{{{ data.description }}}</span>
            <# } #>

            <div class="buttonset">

                <# for ( key in data.choices ) { #>

                    <input type="radio" value="{{ key }}" name="_customize-{{ data.type }}-{{ data.id }}" id="{{ data.id }}-{{ key }}" {{{ data.link }}} <# if ( key === data.value ) { #> checked="checked" <# } #> /> 

                    <label for="{{ data.id }}-{{ key }}">
                        <span class="screen-reader-text">{{ data.choices[ key ]['label'] }}</span>
                        <img src="{{ data.choices[ key ]['url'] }}" title="{{ data.choices[ key ]['label'] }}" alt="{{ data.choices[ key ]['label'] }}" />
                    </label>
                <# } #>

            </div><!-- .buttonset -->
        <?php }
    }

/*--------------------------------------------------------------------------------------------------------------*/
    /**
     * Customize for multiple check boxes
     */
    class Perfect_Plus_Customize_Multiple_Checkboxes_Control extends WP_Customize_Control {
        /**
         * The type of customize control being rendered.
         *
         * @since  1.0.0
         * @access public
         * @var    string
         */
        public $type = 'checkbox-multiple';
        /**
         * Displays the control content.
         *
         * @since  1.0.0
         * @access public
         * @return void
         */
        public function render_content() {

            if ( empty( $this->choices ) ) {
                return;
            }            
    ?>
            <?php if ( !empty( $this->label ) ) : ?>
                <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
            <?php endif; ?>

            <?php if ( !empty( $this->description ) ) : ?>
                <span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
            <?php endif; ?>

            <?php $multi_values = !is_array( $this->value() ) ? explode( ',', $this->value() ) : $this->value(); ?>

            <ul>
                <?php foreach ( $this->choices as $value => $label ) : ?>

                    <li>
                        <label>
                            <input type="checkbox" value="<?php echo esc_attr( $value ); ?>" <?php checked( in_array( $value, $multi_values ) ); ?> /> 
                            <?php echo esc_html( $label ); ?>
                        </label>
                    </li>

                <?php endforeach; ?>
            </ul>

            <input type="hidden" <?php $this->link(); ?> value="<?php echo esc_attr( implode( ',', $multi_values ) ); ?>" />
    <?php
        }
    }

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Customize controls for repeater field
     *
     * @since 1.0.0
     */
    class Perfect_Plus_Repeater_Controler extends WP_Customize_Control {
        /**
         * The control type.
         *
         * @access public
         * @var string
         */
        public $type = 'cv-repeater';

        public $perfect_plus_box_label = '';

        public $perfect_plus_box_add_control = '';

        /**
         * The fields that each container row will contain.
         *
         * @access public
         * @var array
         */
        public $fields = array();

        /**
         * Repeater drag and drop controller
         *
         * @since  1.0.0
         */
        public function __construct( $manager, $id, $args = array(), $fields = array() ) {
            $this->fields = $fields;
            $this->perfect_plus_box_label = $args['perfect_plus_box_label'] ;
            $this->perfect_plus_box_add_control = $args['perfect_plus_box_add_control'];
            parent::__construct( $manager, $id, $args );
        }

        public function render_content() {

            $values = json_decode( $this->value() );
            $repeater_id = $this->id;
            $field_count = count( $values );
        ?>
            <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>

            <?php if( $this->description ){ ?>
                <span class="description customize-control-description">
                    <?php echo wp_kses_post( $this->description ); ?>
                </span>
            <?php } ?>

            <ul class="cv-repeater-field-control-wrap">
                <?php $this->perfect_plus_get_fields(); ?>
            </ul>

            <input type="hidden" <?php $this->link(); ?> class="cv-repeater-collector" value="<?php echo esc_attr( $this->value() ); ?>" />
            <input type="hidden" name="<?php echo esc_attr( $repeater_id ).'_count'; ?>" class="field-count" value="<?php echo absint( $field_count ); ?>">
            <input type="hidden" name="field_limit" class="field-limit" value="6">
            <button type="button" class="button cv-repeater-add-control-field"><?php echo esc_html( $this->perfect_plus_box_add_control ); ?></button>
    <?php
        }

        private function perfect_plus_get_fields(){
            $fields = $this->fields;
            $values = json_decode( $this->value() );

            if( is_array( $values ) ){
            	foreach( $values as $value ){
        ?>
	            <li class="cv-repeater-field-control">
	            <h3 class="cv-repeater-field-title"><?php echo esc_html( $this->perfect_plus_box_label ); ?></h3>
	            
	            <div class="cv-repeater-fields">
	            <?php
	                foreach ( $fields as $key => $field ) {
	                $class = isset( $field['class'] ) ? $field['class'] : '';
	            ?>
	                <div class="cv-repeater-field cv-repeater-type-<?php echo esc_attr( $field['type'] ).' '.esc_attr( $class ); ?>">

	                <?php 
	                    $label = isset( $field['label'] ) ? $field['label'] : '';
	                    $description = isset( $field['description'] ) ? $field['description'] : '';
	                    if( $field['type'] != 'checkbox' ) { 
	                ?>
	                        <span class="customize-control-title"><?php echo esc_html( $label ); ?></span>
	                        <span class="description customize-control-description"><?php echo esc_html( $description ); ?></span>
	                <?php 
	                    }

	                    $new_value = isset( $value->$key ) ? $value->$key : '';
	                    $default = isset( $field['default'] ) ? $field['default'] : '';

	                    switch ( $field['type'] ) {
	                        /**
                             * Text field
                             */
                            case 'text':
	                            echo '<input data-default="'.esc_attr( $default ).'" data-name="'.esc_attr( $key ).'" type="text" value="'.esc_attr( $new_value ).'"/>';
	                            break;

	                        /**
                             * URL field
                             */
                            case 'url':
	                            echo '<input data-default="'.esc_attr( $default ).'" data-name="'.esc_attr( $key ).'" type="text" value="'.esc_url( $new_value ).'"/>';
	                            break;

	                        /**
                             * Icon field
                             */
                            case 'icon':
                                $perfect_plus_font_awesome_icon_array = perfect_plus_font_awesome_icon_array();
	                            echo '<div class="cv-repeater-selected-icon"><i class="'.esc_attr( $new_value ).'"></i><span><i class="fa fa-angle-down"></i></span></div><ul class="cv-repeater-icon-list clearfix">';
                                foreach ( $perfect_plus_font_awesome_icon_array as $perfect_plus_font_awesome_icon ) {
	                                $icon_class = $new_value == $perfect_plus_font_awesome_icon ? 'icon-active' : '';
	                                echo '<li class='.esc_attr( $icon_class ).'><i class="'.esc_attr( $perfect_plus_font_awesome_icon ).'"></i></li>';
	                            }
	                            echo '</ul><input data-default="'.esc_attr( $default ).'" type="hidden" value="'.esc_attr( $new_value ).'" data-name="'.esc_attr( $key ).'"/>';
	                            break;

	                        /**
                             * Social Icon field
                             */
                            case 'social_icon':
                                $perfect_plus_font_awesome_social_icon_array = perfect_plus_font_awesome_social_icon_array();
	                            echo '<div class="cv-repeater-selected-icon"><i class="'.esc_attr( $new_value ).'"></i><span><i class="fa fa-angle-down"></i></span></div><ul class="cv-repeater-icon-list cv-clearfix">';
	                            foreach ( $perfect_plus_font_awesome_social_icon_array as $perfect_plus_font_awesome_icon ) {
	                                $icon_class = $new_value == $perfect_plus_font_awesome_icon ? 'icon-active' : '';
	                                echo '<li class='.esc_attr( $icon_class ).'><i class="'.esc_attr( $perfect_plus_font_awesome_icon ).'"></i></li>';
	                            }
	                            echo '</ul><input data-default="'.esc_attr( $default ).'" type="hidden" value="'.esc_attr( $new_value ).'" data-name="'.esc_attr( $key ).'"/>';
	                            break;

	                        /**
                             * Select field
                             */
                            case 'select':
	                            $options = $field['options'];
	                            echo '<select  data-default="'.esc_attr( $default ).'"  data-name="'.esc_attr( $key ).'">';
	                                foreach ( $options as $option => $val )
	                                {
	                                    printf( '<option value="%1$s" %2$s>%3$s</option>', esc_attr( $option ), selected( $new_value, $option, false ), esc_html( $val ) );
	                                }
	                            echo '</select>';
	                            break;

	                        /**
                             * Dropdown field
                             */
                            case 'dropdown_pages':
								$show_option_none = esc_html__( '&mdash; Select a page &mdash;', 'perfect-plus' );
								$select_field ='data-default="'.esc_attr( $default ).'"  data-name="'.esc_attr( $key ).'"';
								$option_none_value = '';
								$dropdown = wp_dropdown_pages(
									array(
										'name'              => esc_attr( $key ),
										'echo'              => '',
										'show_option_none'  => esc_html( $show_option_none ),
										'option_none_value' => esc_attr( $option_none_value ),
										'selected'          => esc_attr( $new_value )
									)
								);

								if ( empty( $dropdown ) ) {
									$dropdown = sprintf( '<select id="%1$s" name="%1$s">', esc_attr( $key ) );
									$dropdown .= sprintf( '<option value="%1$s">%2$s</option>', esc_attr( $option_none_value ), esc_html( $show_option_none ) );
									$dropdown .= '</select>';
								}

								// Hackily add in the data link parameter.
								$dropdown = str_replace( '<select', '<select ' . $select_field, $dropdown );

								echo $dropdown;
								break;

                            /**
                             * Upload field
                             */
                            case 'upload':
                                $image_class = "";
                                $upload_btn_label = esc_html__( 'Select Image', 'perfect-plus' );
                                $remove_btn_label = esc_html__( 'Remove', 'perfect-plus' );
                                if( $new_value ){ 
                                    $image_class = ' hidden';
                                }
                                echo '<div class="cv-fields-wrap"><div class="attachment-media-view"><div class="placeholder'. esc_attr( $image_class ).'">';
                                esc_html_e( 'No image selected', 'perfect-plus' );
                                echo '</div><div class="thumbnail thumbnail-image"><img src="'.esc_url( $new_value ).'" style="max-width:100%;"/></div><div class="actions clearfix"><button type="button" class="button cv-delete-button align-left">'. esc_html( $remove_btn_label ) .'</button><button type="button" class="button cv-upload-button alignright">'. esc_html( $upload_btn_label ) .'</button><input data-default="'.esc_attr( $default ).'" class="upload-id" data-name="'.esc_attr( $key ).'" type="hidden" value="'.esc_attr( $new_value ).'"/></div></div></div>';
                                break;

	                        default:
	                            break;
	                    }
	                ?>
	                </div>
            <?php
                }
            ?>
	                <div class="cv-clearfix cv-repeater-footer">
	                    <div class="alignright">
	                    <a class="cv-repeater-field-remove" href="#remove"><?php esc_html_e( 'Delete', 'perfect-plus' ) ?></a> |
	                    <a class="cv-repeater-field-close" href="#close"><?php esc_html_e( 'Close', 'perfect-plus' ) ?></a>
	                    </div>
	                </div><!-- .cv-repeater-footer -->
	            </div><!-- .cv-repeater-fields-->
	            </li>
        <?php   
            	}
            }
        }
    }
}