<?php
/**
 * Perfect Plus Footer Settings panel at Theme Customizer
 *
 * @package CodeVibrant
 * @subpackage Perfect Plus
 * @since 1.0.0
 */

add_action( 'customize_register', 'perfect_plus_footer_settings_register' );

function perfect_plus_footer_settings_register( $wp_customize ) {

    $wp_customize->register_control_type( 'Perfect_Plus_Customize_Control_Radio_Image' );

    /**
     * Add Footer Settings Panel
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel(
	    'perfect_plus_footer_settings_panel',
	    array(
	        'priority'       => 35,
	        'capability'     => 'edit_theme_options',
	        'theme_supports' => '',
	        'title'          => __( 'Footer Settings', 'perfect-plus' ),
	    )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    
    /**
     * Widget area section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'perfect_plus_footer_widget_area_section',
        array(
            'priority'       => 5,
            'panel'          => 'perfect_plus_footer_settings_panel',
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'Widget Area Section', 'perfect-plus' )
        )
    );

    /**
     * Checkbox toggle for footer widget area section
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'footer_widget_area_option',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => true,
            'sanitize_callback' => 'perfect_plus_sanitize_checkbox',
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Toggle_Checkbox_Custom_Control(
        $wp_customize, 
        'footer_widget_area_option',
        array(
            'label'         => __( 'Section Option', 'perfect-plus' ),
            'description'   => __( 'Set option for Footer Widget Area section.', 'perfect-plus' ),
            'section'       => 'perfect_plus_footer_widget_area_section',
            'settings'      => 'footer_widget_area_option',
            'priority'      => 5
        )
    ));

    /**
     * Radio image field for footer widget area
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'perfect_plus_footer_widget_layout',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'column_four',
            'sanitize_callback' => 'perfect_plus_sanitize_select',
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Customize_Control_Radio_Image(
        $wp_customize,
        'perfect_plus_footer_widget_layout',
            array(
                'label'         => __( 'Widget Area Layout', 'perfect-plus' ),
                'description'   => __( 'Choose layout from available layouts', 'perfect-plus' ),
                'section'       => 'perfect_plus_footer_widget_area_section',
                'settings'      => 'perfect_plus_footer_widget_layout',
                'priority'      => 10,
                'choices'       => array(
                    'column_one'      => array(
                        'label'       => __( 'Column One', 'perfect-plus' ),
                        'url'         => '%s/assets/images/footer-1.png'
                    ),
                    'column_two'      => array(
                        'label'       => __( 'Columns Two', 'perfect-plus' ),
                        'url'         => '%s/assets/images/footer-2.png'
                    ),
                    'column_three'    => array(
                        'label'       => __( 'Columns Three', 'perfect-plus' ),
                        'url'         => '%s/assets/images/footer-3.png'
                    ),
                    'column_four'     => array(
                        'label'       => __( 'Columns Four', 'perfect-plus' ),
                        'url'         => '%s/assets/images/footer-4.png'
                    )
                )
            )
        )
    );

    /**
     * Text field for copyright
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'cv_copyright_text',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => __( 'Perfect Plus', 'perfect-plus' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'cv_copyright_text',
        array(
            'label'         => __( 'Copyright Text', 'perfect-plus' ),
            'section'       => 'perfect_plus_footer_widget_area_section',
            'settings'      => 'cv_copyright_text',
            'type'          => 'text',
            'priority'      => 15
        )
    );

}