<?php
/**
 * Perfect Plus HomePage Settings panel at Theme Customizer
 *
 * @package CodeVibrant
 * @subpackage Perfect Plus
 * @since 1.0.0
 */

add_action( 'customize_register', 'perfect_plus_homepage_settings_register' );

function perfect_plus_homepage_settings_register( $wp_customize ) {

    /**
     * Add HomePage Settings Panel
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel(
	    'perfect_plus_homepage_settings_panel',
	    array(
	        'priority'       => 15,
	        'capability'     => 'edit_theme_options',
	        'theme_supports' => '',
	        'title'          => __( 'Home Page Sections', 'perfect-plus' ),
	    )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
	/**
     * Slider section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'perfect_plus_slider_section',
        array(
        	'priority'       => 5,
        	'panel'          => 'perfect_plus_homepage_settings_panel',
        	'capability'     => 'edit_theme_options',
        	'theme_supports' => '',
            'title'          => __( 'Slider Section', 'perfect-plus' ),
            'description'    => __( 'Managed the content for homepage slider.', 'perfect-plus' ),
        )
    );

    /**
     * Checkbox toggle for show home content
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_slider_option',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => true,
            'sanitize_callback' => 'perfect_plus_sanitize_checkbox',
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Toggle_Checkbox_Custom_Control(
        $wp_customize, 
        'home_slider_option',
        array(
            'label'         => __( 'Section Option', 'perfect-plus' ),
            'description'   => __( 'Set option for slider section at homepage.', 'perfect-plus' ),
            'section'       => 'perfect_plus_slider_section',
            'settings'      => 'home_slider_option',
            'priority'      => 5
        )
    ));

    /**
     * Repeater field for single slide
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_slides', 
        array(
            'capability'       => 'edit_theme_options',
            'default'          => json_encode(array(
                    array(
                        'cv_select_pages' => '',
                        'cv_select_field' => 'center_align',
                        'cv_text_field'   => __( 'Read More', 'perfect-plus' )
                    )
                )
            ),
            'sanitize_callback' => 'perfect_plus_sanitize_repeater'
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Repeater_Controler(
        $wp_customize, 
            'home_slides', 
            array(
                'label'           => __( 'Home Page Slides', 'perfect-plus' ),
                'section'         => 'perfect_plus_slider_section',
                'settings'        => 'home_slides',
                'priority'        => 5,
                'perfect_plus_box_label'       => __( 'Single Slide','perfect-plus' ),
                'perfect_plus_box_add_control' => __( 'Add Slide','perfect-plus' )
            ),
            array(
                'cv_select_pages' => array(
                    'type'        => 'dropdown_pages',
                    'label'       => __( 'Select Page', 'perfect-plus' ),
                    'description' => __( 'Choose a page for a single slide.', 'perfect-plus' )
                ),
                'cv_select_field' => array(
					'type'        => 'select',
					'label'       => __( 'Select Text Alignment', 'perfect-plus' ),
					'description' => __( 'Managed the slider content alignment.', 'perfect-plus' ),
					'options' 	  => array(
							'left_align' 	=> __( 'Left Alignment', 'perfect-plus' ),
							'center_align' 	=> __( 'Center Alignment', 'perfect-plus' ),
							'right_align' 	=> __( 'Right Alignment', 'perfect-plus' ),
					),
					'default'     => 'center_align'
				),
                'cv_text_field' => array(
                    'type'        => 'text',
                    'label'       => __( 'Slide Button Text', 'perfect-plus' ),
                    'description' => __( 'Add read more button text.', 'perfect-plus' ),
                    'default'     => __( 'Read More', 'perfect-plus' )
                ),
            )
        ) 
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Service section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'perfect_plus_service_section',
        array(
            'priority'       => 10,
            'panel'          => 'perfect_plus_homepage_settings_panel',
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'Service Section', 'perfect-plus' ),
            'description'    => __( 'Managed the content for homepage service section.', 'perfect-plus' ),
        )
    );

    /**
     * Checkbox toggle for controlling service content
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_service_option',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => true,
            'sanitize_callback' => 'perfect_plus_sanitize_checkbox',
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Toggle_Checkbox_Custom_Control(
        $wp_customize, 
        'home_service_option',
        array(
            'label'         => __( 'Section Option', 'perfect-plus' ),
            'description'   => __( 'Set option for service section at homepage.', 'perfect-plus' ),
            'section'       => 'perfect_plus_service_section',
            'settings'      => 'home_service_option',
            'priority'      => 5
        )
    ));

    /**
     * Text field for section title
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_service_title',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => __( 'Our Services', 'perfect-plus' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'home_service_title',
        array(
            'label'         => __( 'Section Title', 'perfect-plus' ),
            'section'       => 'perfect_plus_service_section',
            'settings'      => 'home_service_title',
            'type'          => 'text',
            'priority'      => 10
        )
    );

    /**
     * Text field for section item read more
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_service_read_more_text',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => __( 'Read More', 'perfect-plus' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'home_service_read_more_text',
        array(
            'label'         => __( 'Read More Text', 'perfect-plus' ),
            'section'       => 'perfect_plus_service_section',
            'settings'      => 'home_service_read_more_text',
            'type'          => 'text',
            'priority'      => 20
        )
    );

    /**
     * Repeater field for single service item
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting( 
        'home_service_items', 
        array(
            'capability'       => 'edit_theme_options',
            'default'          => json_encode(array(
                    array(
                        'cv_select_pages' => '',
                        'cv_icons_list'   => 'fa fa-diamond',
                    )
                )
            ),
            'sanitize_callback' => 'perfect_plus_sanitize_repeater'
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Repeater_Controler(
        $wp_customize, 
            'home_service_items', 
            array(
                'label'           => __( 'Section Items', 'perfect-plus' ),
                'section'         => 'perfect_plus_service_section',
                'settings'        => 'home_service_items',
                'priority'        => 25,
                'perfect_plus_box_label'       => __( 'Single Item','perfect-plus' ),
                'perfect_plus_box_add_control' => __( 'Add Item','perfect-plus' )
            ),
            array(
                'cv_select_pages' => array(
                    'type'        => 'dropdown_pages',
                    'label'       => __( 'Select Page', 'perfect-plus' ),
                    'description' => __( 'Choose a page for a single item.', 'perfect-plus' )
                ),
                'cv_icons_list' => array(
                    'type'        => 'icon',
                    'label'       => __( 'Select Icons', 'perfect-plus' ),
                    'description' => __( 'Select the suitable icon from font awesome icons list.', 'perfect-plus' ),
                    'default'     => 'fa fa-diamond'
                )
            )
        ) 
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * About Us section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'perfect_plus_about_us_section',
        array(
            'priority'       => 15,
            'panel'          => 'perfect_plus_homepage_settings_panel',
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'About Us Section', 'perfect-plus' ),
            'description'    => __( 'Managed the content for homepage about us section.', 'perfect-plus' ),
        )
    );

    /**
     * Checkbox toggle for controlling service content
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_about_us_option',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => true,
            'sanitize_callback' => 'perfect_plus_sanitize_checkbox',
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Toggle_Checkbox_Custom_Control(
        $wp_customize, 
        'home_about_us_option',
        array(
            'label'         => __( 'Section Option', 'perfect-plus' ),
            'description'   => __( 'Set option for about us section at homepage.', 'perfect-plus' ),
            'section'       => 'perfect_plus_about_us_section',
            'settings'      => 'home_about_us_option',
            'priority'      => 5
        )
    ));

    /**
     * drop down field for section page
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_about_us_page',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 0,
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'home_about_us_page',
        array(
            'label'         => __( 'Section Page', 'perfect-plus' ),
            'section'       => 'perfect_plus_about_us_section',
            'settings'      => 'home_about_us_page',
            'type'          => 'dropdown-pages',
            'priority'      => 10
        )
    );

    /**
     * Text field for section read-more
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_about_read_more_text',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => __( 'Read More', 'perfect-plus' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'home_about_read_more_text',
        array(
            'label'         => __( 'Read More Text', 'perfect-plus' ),
            'section'       => 'perfect_plus_about_us_section',
            'settings'      => 'home_about_read_more_text',
            'type'          => 'text',
            'priority'      => 15
        )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Portfolio section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'perfect_plus_portfolio_section',
        array(
            'priority'       => 20,
            'panel'          => 'perfect_plus_homepage_settings_panel',
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'Portfolio Section', 'perfect-plus' ),
            'description'    => __( 'Managed the content for homepage portfolio section.', 'perfect-plus' ),
        )
    );

    /**
     * Checkbox toggle for controlling portfolio content
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_portfolio_option',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => true,
            'sanitize_callback' => 'perfect_plus_sanitize_checkbox',
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Toggle_Checkbox_Custom_Control(
        $wp_customize, 
        'home_portfolio_option',
        array(
            'label'         => __( 'Section Option', 'perfect-plus' ),
            'description'   => __( 'Set option for portfolio section at homepage.', 'perfect-plus' ),
            'section'       => 'perfect_plus_portfolio_section',
            'settings'      => 'home_portfolio_option',
            'priority'      => 5
        )
    ));

    /**
     * Text field for section title
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_portfolio_title',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => __( 'Our Portfolio', 'perfect-plus' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'home_portfolio_title',
        array(
            'label'         => __( 'Section Title', 'perfect-plus' ),
            'section'       => 'perfect_plus_portfolio_section',
            'settings'      => 'home_portfolio_title',
            'type'          => 'text',
            'priority'      => 10
        )
    );

    /**
     * Multicheckboxes field to listed categories in portfolio section.
     *
     * @since 1.0.0
     */

    $perfect_plus_categories_lists = perfect_plus_categories_lists();

    $wp_customize->add_setting(
        'home_portfolio_cat_slugs',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Customize_Multiple_Checkboxes_Control(
        $wp_customize,
            'home_portfolio_cat_slugs',
            array(
                'label'         => __( 'Portfolios Categories', 'perfect-plus' ),
                'description'   => __( 'Choose categories to manage portfolios posts.', 'perfect-plus' ),
                'section'       => 'perfect_plus_portfolio_section',
                'settings'      => 'home_portfolio_cat_slugs',                
                'priority'      => 20,
                'choices'       => $perfect_plus_categories_lists
            )
        )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Call To Action section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'perfect_plus_cta_section',
        array(
            'priority'       => 25,
            'panel'          => 'perfect_plus_homepage_settings_panel',
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'Call To Action Section', 'perfect-plus' ),
            'description'    => __( 'Managed the content for homepage call to action section.', 'perfect-plus' ),
        )
    );

    /**
     * Checkbox toggle for controlling sponsor content
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_cta_option',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => true,
            'sanitize_callback' => 'perfect_plus_sanitize_checkbox',
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Toggle_Checkbox_Custom_Control(
        $wp_customize, 
        'home_cta_option',
        array(
            'label'         => __( 'Section Option', 'perfect-plus' ),
            'description'   => __( 'Set option for call to action section at homepage.', 'perfect-plus' ),
            'section'       => 'perfect_plus_cta_section',
            'settings'      => 'home_cta_option',
            'priority'      => 5
        )
    ));

    /**
     * Text field for section title
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_cta_bg_image',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => '',
            'sanitize_callback' => 'esc_url_raw',
        )
    );
    $wp_customize->add_control( new WP_Customize_Image_Control (
        $wp_customize,
        'home_cta_bg_image',
        array(
            'label'         => __( 'Section Background Image', 'perfect-plus' ),
            'section'       => 'perfect_plus_cta_section',
            'settings'      => 'home_cta_bg_image',
            'type'          => 'upload',
            'priority'      => 10
        )
    ));

    /**
     * Textarea field for section information
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_cta_content',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => '',
            'sanitize_callback' => 'wp_kses_post',
        )
    );
    $wp_customize->add_control(
        'home_cta_content',
        array(
            'label'         => __( 'Section Content', 'perfect-plus' ),
            'description'   => __( 'Add plain or HTML content for call to action.', 'perfect-plus' ),
            'section'       => 'perfect_plus_cta_section',
            'settings'      => 'home_cta_content',
            'type'          => 'textarea',
            'priority'      => 15
        )
    );

    /**
     * Text field for button text
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_cta_btn_text',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => __( 'Explore', 'perfect-plus' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'home_cta_btn_text',
        array(
            'label'         => __( 'Button Label', 'perfect-plus' ),
            'section'       => 'perfect_plus_cta_section',
            'settings'      => 'home_cta_btn_text',
            'type'          => 'text',
            'priority'      => 20
        )
    );

    /**
     * Text field for button url
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_cta_btn_url',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => '#',
            'sanitize_callback' => 'esc_url_raw',
        )
    );
    $wp_customize->add_control(
        'home_cta_btn_url',
        array(
            'label'         => __( 'Button Link', 'perfect-plus' ),
            'section'       => 'perfect_plus_cta_section',
            'settings'      => 'home_cta_btn_url',
            'type'          => 'text',
            'priority'      => 25
        )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Team Member section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'perfect_plus_team_member_section',
        array(
            'priority'       => 30,
            'panel'          => 'perfect_plus_homepage_settings_panel',
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'Team Member Section', 'perfect-plus' ),
            'description'    => __( 'Managed the content for homepage team member section.', 'perfect-plus' ),
        )
    );

    /**
     * Checkbox toggle for controlling team member content
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_team_member_option',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => true,
            'sanitize_callback' => 'perfect_plus_sanitize_checkbox',
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Toggle_Checkbox_Custom_Control(
        $wp_customize, 
        'home_team_member_option',
        array(
            'label'         => __( 'Section Option', 'perfect-plus' ),
            'description'   => __( 'Set option for team member section at homepage.', 'perfect-plus' ),
            'section'       => 'perfect_plus_team_member_section',
            'settings'      => 'home_team_member_option',
            'priority'      => 5
        )
    ));

    /**
     * Text field for section title
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_team_member_title',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => __( 'Our Team Members', 'perfect-plus' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'home_team_member_title',
        array(
            'label'         => __( 'Section Title', 'perfect-plus' ),
            'section'       => 'perfect_plus_team_member_section',
            'settings'      => 'home_team_member_title',
            'type'          => 'text',
            'priority'      => 10
        )
    );

    /**
     * Repeater field for single team member item
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting( 
        'home_team_member_items', 
        array(
            'capability'       => 'edit_theme_options',
            'default'          => json_encode(array(
                    array(
                        'cv_select_pages' => '',
                        'cv_text_field'   => '',
                    )
                )
            ),
            'sanitize_callback' => 'perfect_plus_sanitize_repeater'
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Repeater_Controler(
        $wp_customize, 
            'home_team_member_items', 
            array(
                'label'           => __( 'Section Members', 'perfect-plus' ),
                'section'         => 'perfect_plus_team_member_section',
                'settings'        => 'home_team_member_items',
                'priority'        => 20,
                'perfect_plus_box_label'       => __( 'Single Member','perfect-plus' ),
                'perfect_plus_box_add_control' => __( 'Add Member','perfect-plus' )
            ),
            array(
                'cv_select_pages' => array(
                    'type'        => 'dropdown_pages',
                    'label'       => __( 'Select Page', 'perfect-plus' ),
                    'description' => __( 'Choose a page for a single member.', 'perfect-plus' )
                ),
                'cv_text_field' => array(
                    'type'        => 'text',
                    'label'       => __( 'Member Info', 'perfect-plus' ),
                    'description' => __( 'Add a short info about team member.', 'perfect-plus' )
                )
            )
        )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Latest blog section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'perfect_plus_latest_blog_section',
        array(
            'priority'       => 35,
            'panel'          => 'perfect_plus_homepage_settings_panel',
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'Latest Blog Section', 'perfect-plus' ),
            'description'    => __( 'Managed the content for homepage latest blog section.', 'perfect-plus' ),
        )
    );

    /**
     * Checkbox toggle for controlling latest blog content
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_latest_blog_option',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => true,
            'sanitize_callback' => 'perfect_plus_sanitize_checkbox',
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Toggle_Checkbox_Custom_Control(
        $wp_customize, 
        'home_latest_blog_option',
        array(
            'label'         => __( 'Section Option', 'perfect-plus' ),
            'description'   => __( 'Set option for latest blog section at homepage.', 'perfect-plus' ),
            'section'       => 'perfect_plus_latest_blog_section',
            'settings'      => 'home_latest_blog_option',
            'priority'      => 5
        )
    ));

    /**
     * Text field for section title
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_latest_blog_title',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => __( 'Latest Blogs', 'perfect-plus' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'home_latest_blog_title',
        array(
            'label'         => __( 'Section Title', 'perfect-plus' ),
            'section'       => 'perfect_plus_latest_blog_section',
            'settings'      => 'home_latest_blog_title',
            'type'          => 'text',
            'priority'      => 10
        )
    );

    /**
     * Multicheckboxes field to listed categories in latest blog section.
     *
     * @since 1.0.0
     */

    $perfect_plus_categories_lists = perfect_plus_categories_lists();

    $wp_customize->add_setting(
        'home_latest_blog_cat_slugs',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Customize_Multiple_Checkboxes_Control(
        $wp_customize,
            'home_latest_blog_cat_slugs',
            array(
                'label'         => __( 'Latest Blog Categories', 'perfect-plus' ),
                'description'   => __( 'Choose categories to manage latest blogs.', 'perfect-plus' ),
                'section'       => 'perfect_plus_latest_blog_section',
                'settings'      => 'home_latest_blog_cat_slugs',                
                'priority'      => 20,
                'choices'       => $perfect_plus_categories_lists
            )
        )
    );

    /**
     * Text field for section read more text
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_latest_blog_read_more_text',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => __( 'Discover', 'perfect-plus' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'home_latest_blog_read_more_text',
        array(
            'label'         => __( 'Read More Text', 'perfect-plus' ),
            'section'       => 'perfect_plus_latest_blog_section',
            'settings'      => 'home_latest_blog_read_more_text',
            'type'          => 'text',
            'priority'      => 25
        )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Testimonials section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'perfect_plus_testimonials_section',
        array(
            'priority'       => 40,
            'panel'          => 'perfect_plus_homepage_settings_panel',
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'Testimonials Section', 'perfect-plus' ),
            'description'    => __( 'Managed the content for homepage testimonials section.', 'perfect-plus' ),
        )
    );

    /**
     * Checkbox toggle for controlling testimonials content
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_testimonials_option',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => true,
            'sanitize_callback' => 'perfect_plus_sanitize_checkbox',
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Toggle_Checkbox_Custom_Control(
        $wp_customize, 
        'home_testimonials_option',
        array(
            'label'         => __( 'Section Option', 'perfect-plus' ),
            'description'   => __( 'Set option for testimonials section at homepage.', 'perfect-plus' ),
            'section'       => 'perfect_plus_testimonials_section',
            'settings'      => 'home_testimonials_option',
            'priority'      => 5
        )
    ));

    /**
     * Text field for section title
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_testimonials_title',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => __( 'Client Testimonials', 'perfect-plus' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'home_testimonials_title',
        array(
            'label'         => __( 'Section Title', 'perfect-plus' ),
            'section'       => 'perfect_plus_testimonials_section',
            'settings'      => 'home_testimonials_title',
            'type'          => 'text',
            'priority'      => 10
        )
    );

    /**
     * Repeater field for single testimonials item
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting( 
        'home_testimonials_items', 
        array(
            'capability'       => 'edit_theme_options',
            'default'          => json_encode(array(
                    array(
                        'cv_select_pages' => '',
                        'cv_text_field'   => '',
                    )
                )
            ),
            'sanitize_callback' => 'perfect_plus_sanitize_repeater'
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Repeater_Controler(
        $wp_customize, 
            'home_testimonials_items', 
            array(
                'label'           => __( 'Section Items', 'perfect-plus' ),
                'section'         => 'perfect_plus_testimonials_section',
                'settings'        => 'home_testimonials_items',
                'priority'        => 20,
                'perfect_plus_box_label'       => __( 'Single Item','perfect-plus' ),
                'perfect_plus_box_add_control' => __( 'Add Item','perfect-plus' )
            ),
            array(
                'cv_select_pages' => array(
                    'type'        => 'dropdown_pages',
                    'label'       => __( 'Select Page', 'perfect-plus' ),
                    'description' => __( 'Choose a page for a single item.', 'perfect-plus' )
                ),
                'cv_text_field' => array(
                    'type'        => 'text',
                    'label'       => __( 'Author Info', 'perfect-plus' ),
                    'description' => __( 'Add a short info about author like author company with designation.', 'perfect-plus' )
                )
            )
        )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Sponsor section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'perfect_plus_sponsor_section',
        array(
            'priority'       => 45,
            'panel'          => 'perfect_plus_homepage_settings_panel',
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'Sponsor Section', 'perfect-plus' ),
            'description'    => __( 'Managed the content for homepage sponsor section.', 'perfect-plus' ),
        )
    );

    /**
     * Checkbox toggle for controlling sponsor content
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_sponsor_option',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => true,
            'sanitize_callback' => 'perfect_plus_sanitize_checkbox',
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Toggle_Checkbox_Custom_Control(
        $wp_customize, 
        'home_sponsor_option',
        array(
            'label'         => __( 'Section Option', 'perfect-plus' ),
            'description'   => __( 'Set option for sponsor section at homepage.', 'perfect-plus' ),
            'section'       => 'perfect_plus_sponsor_section',
            'settings'      => 'home_sponsor_option',
            'priority'      => 5
        )
    ));

    /**
     * Text field for section title
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'home_sponsor_title',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => __( 'Our Sponsor', 'perfect-plus' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'home_sponsor_title',
        array(
            'label'         => __( 'Section Title', 'perfect-plus' ),
            'section'       => 'perfect_plus_sponsor_section',
            'settings'      => 'home_sponsor_title',
            'type'          => 'text',
            'priority'      => 10
        )
    );

    /**
     * Repeater field for single sponsor item
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting( 
        'home_sponsor_items', 
        array(
            'capability'       => 'edit_theme_options',
            'default'          => json_encode(array(
                    array(
                        'cv_upload_field'   => ''
                    )
                )
            ),
            'sanitize_callback' => 'perfect_plus_sanitize_repeater'
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Repeater_Controler(
        $wp_customize, 
            'home_sponsor_items', 
            array(
                'label'           => __( 'Section Items', 'perfect-plus' ),
                'section'         => 'perfect_plus_sponsor_section',
                'settings'        => 'home_sponsor_items',
                'priority'        => 20,
                'perfect_plus_box_label'       => __( 'Sponsors','perfect-plus' ),
                'perfect_plus_box_add_control' => __( 'Add Sponsor','perfect-plus' )
            ),
            array(
                'cv_upload_field' => array(
                    'type'        => 'upload',
                    'label'       => __( 'Select Image', 'perfect-plus' ),
                    'description' => __( 'Upload a image as sponsor logo.', 'perfect-plus' )
                )
            )
        )
    );

    
}