<?php
/**
 * Create a metabox to managed sidebar layout on each posts and pages.
 *
 * @package CodeVibrant
 * @subpackage Perfect Plus
 * @since 1.0.0
 */

/*----------------------------------------------------------------------------------------------------------------------------------------*/
add_action( 'add_meta_boxes', 'perfect_plus_sidebar_meta_options' );
 
if( ! function_exists( 'perfect_plus_sidebar_meta_options' ) ):
	function  perfect_plus_sidebar_meta_options() {
		add_meta_box(
			'perfect_plus_sidebar_meta',
			__( 'Sidebar Layout', 'perfect-plus' ),
			'perfect_plus_sidebar_meta_callback',
			'post',
			'normal',
			'high'
		);
 	}
endif;

/*----------------------------------------------------------------------------------------------------------------------------------------*/

if( ! function_exists( 'perfect_plus_sidebar_meta_callback' ) ) :
	/**
	 * Callback function for post option
	 */
	function perfect_plus_sidebar_meta_callback( $post ) {

		$perfect_plus_sidebar_options = array(
			'default-sidebar' => array(
					'id'		=> 'post-default-sidebar',
					'value'		=> 'default_sidebar',
					'label'		=> __( 'Default Sidebar', 'perfect-plus' ),
					'thumbnail'	=> get_template_directory_uri() . '/assets/images/default-sidebar.png'
				), 
			'left-sidebar' => array(
					'id'		=> 'post-right-sidebar',
					'value'		=> 'left_sidebar',
					'label'		=> __( 'Left sidebar', 'perfect-plus' ),
					'thumbnail' => get_template_directory_uri() . '/assets/images/left-sidebar.png'
				), 
			'right-sidebar' => array(
					'id'		=> 'post-left-sidebar',
					'value'		=> 'right_sidebar',
					'label'		=> __( 'Right sidebar', 'perfect-plus' ),
					'thumbnail' => get_template_directory_uri() . '/assets/images/right-sidebar.png'
				),
			'no-sidebar' => array(
					'id'		=> 'post-no-sidebar',
					'value'		=> 'no_sidebar',
					'label'		=> __( 'No sidebar Full width', 'perfect-plus' ),
					'thumbnail' => get_template_directory_uri() . '/assets/images/no-sidebar.png'
				),
			'no-sidebar-center' => array(
					'id'		=> 'post-no-sidebar-center',
					'value'		=> 'no_sidebar_center',
					'label'		=> __( 'No sidebar Content Centered', 'perfect-plus' ),
					'thumbnail' => get_template_directory_uri() . '/assets/images/no-sidebar-center.png'
				)
		);

		// Check for previously set.
		$sidebar_layout = get_post_meta( $post->ID, 'perfect_plus_sidebar_location', true );
		$sidebar_layout = ( $sidebar_layout ) ? $sidebar_layout : 'default_sidebar';

		wp_nonce_field( 'perfect_plus_nonce_' . basename( __FILE__ ) , 'perfect_plus_sidebar_location_nonce' );
	?>
		<div class="cv-meta-options-wrap">
			<div class="buttonset">
				<?php foreach ( $perfect_plus_sidebar_options as $layout ) { ?>
						<input type="radio" id="<?php echo esc_attr( $layout['id'] ); ?>" value="<?php echo esc_attr( $layout['value'] ); ?>" name="perfect_plus_sidebar_location" <?php checked( $layout['value'], $sidebar_layout ); ?> />
						<label for="<?php echo esc_attr( $layout['id'] ); ?>">
							<span class="screen-reader-text"><?php echo esc_html( $layout['label'] ); ?></span>
							<img src="<?php echo esc_url( $layout['thumbnail'] ); ?>" title="<?php echo esc_attr( $layout['label'] ); ?>" alt="<?php echo esc_attr( $layout['label'] ); ?>" />
						</label>
				<?php } ?>
			</div><!-- .buttonset -->
		</div><!-- .meta-options-wrap  -->
	<?php
	}
endif;

/*----------------------------------------------------------------------------------------------------------------------------------------*/

if( ! function_exists( 'perfect_plus_save_sidebar_meta' ) ):
	/**
	 * Save the post sidebar layout
	 */
	function perfect_plus_save_sidebar_meta( $post_id ) {

		// Checks save status
		$is_autosave = wp_is_post_autosave( $post_id );
		$is_revision = wp_is_post_revision( $post_id );

		$is_valid_nonce = ( isset( $_POST['perfect_plus_sidebar_location_nonce'] ) && wp_verify_nonce( $_POST['perfect_plus_sidebar_location_nonce'], 'perfect_plus_nonce_' . basename( __FILE__ ) ) ) ? 'true' : 'false';

		// Exits script depending on save status
		if ( $is_autosave || $is_revision || ! $is_valid_nonce ) {
			return;
		}

		// Check for out input value.
		if ( isset( $_POST['perfect_plus_sidebar_location'] ) ) {
			// We validate making sure that the option is something we can expect.
			$value = in_array( $_POST['perfect_plus_sidebar_location'], array( 'no_sidebar', 'left_sidebar', 'right_sidebar', 'no_sidebar_center', 'default_sidebar' ) ) ? $_POST['perfect_plus_sidebar_location'] : 'default_sidebar';
			// We update our post meta.
			update_post_meta( $post_id, 'perfect_plus_sidebar_location', $value );
		}
	}
endif;

add_action( 'save_post', 'perfect_plus_save_sidebar_meta' );